@@ -9,28 +9,6 @@ use base qw{Elive};
 
 __PACKAGE__->mk_classdata('element_class');
 
-=for later
-sub BUILDARGS {
-    my $class = shift;
-    my $raw = shift;
-    my @args = @_;
-
-    warn "$class - ignoring arguments to new: @args"
-	if @args;
-
-    if (Elive::Util::_reftype($raw) eq 'ARRAY') {
-
-	my $element_class = $class->element_class
-	    if $class->can('element_class');
-
-	return [map {$element_class->BUILDARGS($_, @args)} @$raw]
-	    if $element_class && $element_class->can('BUILDARGS');
-    }
-
-    return $raw;
-}
-=cut
-
 coerce 'Elive::Array' => from 'Str'
           => via {
 	      my $a = [ split(';') ];
@@ -62,7 +40,7 @@ Elive::Entity::participantList.
 
 =head2 stringify
 
-Stringifies arrays members by joining their sting values with ';'.
+Stringifies arrays members by joining their string values with ';'.
 
 =cut
 
