@@ -61,7 +61,6 @@ for group selection of meeting participants.
      },
     );
 
-
 Inserts a new group from data.
 
 =cut
@@ -72,12 +71,6 @@ Inserts a new group from data.
 
 =cut
 
-sub construct {
-    my $self = shift->SUPER::construct(@_);
-    bless $self->members, 'Elive::Array';
-    $self;
-}
-
 #
 # Seems that elluminate 9.7 can return a single element containing
 # the members, each separated by ';'.
